import 'package:cookbook/data/data_sources/firebase_auth_source.dart';
import 'package:cookbook/domain/entities/auth_user.dart';
import 'package:cookbook/domain/entities/failures/failure.dart';
import 'package:cookbook/domain/repo/auth_repository.dart';
import 'package:either_dart/either.dart';

class FirebaseAuthRepositoryImpl extends AuthRepository {
  final FirebaseAuthSource _dataSource;

  FirebaseAuthRepositoryImpl(this._dataSource);

  @override
  Future<Either<Failure, AuthUser?>> getLoggedUser() {
    var user = _dataSource.getLoggedUser();
    if (user.isLeft) {
      return Future.value(Left(user.left.toEntity()));
    } else {
      return Future.value(Right(user.right?.toEntity()));
    }
  }

  @override
  Future<Either<Failure, AuthUser>> signInWithGoogle() async {
    var user = await _dataSource.signInWithGoogle();
    if (user.isLeft) {
      return Left(user.left.toEntity());
    } else {
      return Right(user.right!.toEntity());
    }
  }

  @override
  Future<Either<Failure, AuthUser?>> signOutUser() async {
    var user = _dataSource.getLoggedUser();
    if (user.isLeft) {
      return Future.value(Left(user.left.toEntity()));
    } else {
      return const Right(null);
    }
  }
}
