import 'package:cookbook/domain/usecases/get_logged_user_usecase.dart';
import 'package:cookbook/domain/usecases/login_user_usecase.dart';
import 'package:cookbook/domain/usecases/signout_user_usecase.dart';
import 'package:get/get.dart';


class HomeController extends GetxController {
  LoginUserUsecase loginUserUsecase;
  GetLoggedUserUsecase getLoggedUserUsecase;
  SignOutUserUsecase signOutUserUsecase;

  bool isUserLoggedIn = false;
  

  HomeController({
    required this.loginUserUsecase,
    required this.getLoggedUserUsecase,
    required this.signOutUserUsecase,
  });

  @override
  Future<void> onInit() async {
    super.onInit();

    var result = await getLoggedUserUsecase.execute();
    if (result.isRight) {
      isUserLoggedIn = true;
    }
    else {
      isUserLoggedIn = false;
    }
  }

  void signIn() async {
    isUserLoggedIn = false;
    var result = await loginUserUsecase.execute();
    if (result.isLeft) {
      Get.snackbar(
        'Error',
        result.left.message,
        snackPosition: SnackPosition.BOTTOM,
      );
    } else {
      isUserLoggedIn = true;
      Get.snackbar('Logged in', result.right!.name);
    }
  }

  void signOut() async {
    var result = await signOutUserUsecase.execute();
    if (result.isLeft) {
      Get.snackbar(
        'Error',
        result.left.message,
        snackPosition: SnackPosition.BOTTOM,
      );
    } else {
      isUserLoggedIn = false;
      Get.snackbar('Logged out', 'You have been logged out');
    }
  }
}
